<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: فارسی [IR]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=419
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "فارسی";
$lang_info['country'] = "ایران";
$lang_info['direction'] = "rtl";
$lang_info['code'] = "Fa";
$lang_info['zero_plural'] = "1";

$lang['%d Kb'] = "%d Kb";
$lang['%d album updated'] = "دسته %d بروز رسانی شد";
$lang['%d albums updated'] = "دسته‌های %d بروزرسانی شدند";
$lang['%d comment to validate'] = "%d تایید شد.";
$lang['%d comments to validate'] = "%d تایید شدند";
$lang['%d new comment'] = "%d نظر جدید";
$lang['%d new comments'] = "%d نظر جدید";
$lang['%d comment'] = "%d نظر";
$lang['%d comments'] = "%d نظر";
$lang['%d hit'] = "%d بازدید";
$lang['%d hits'] = "%d بازدید";
$lang['%d new photo'] = "%d عکس جدید";
$lang['%d new photos'] = "%d عکس جدید";
$lang['%d new user'] = "%d کاربر جدید";
$lang['%d new users'] = "%d کاربر جدید";
$lang['About'] = "درباره";
$lang['All tags'] = "همه‌ی برچسب‌ها";
$lang['Any tag'] = "هر برچسبی";
$lang['At least one listed rule must be satisfied.'] = "حداقل یکی از معیارهای ذکر شده باید مطابقت داشته باشند";
$lang['At least one tag must match'] = "حداقل یک برچسب باید مطابقت داشته باشد";
$lang['Author'] = "نویسنده";
$lang['Albums'] = "دسته‌ها";
$lang['Album'] = "دسته";
$lang['Close this window'] = "بستن این پنجره";
$lang['Complete RSS feed (photos, comments)'] = "خوراک RSS کامل (عکس ها, نظرات)";
$lang['Confirm Password'] = "تایید گذرواژه";
$lang['Connection settings'] = "تنظیمات اتصال";
$lang['Login'] = "ورود";
$lang['Contact webmaster'] = "ارتباط با مدیر";
$lang['Create a new account'] = "ایجاد حساب جدید";
$lang['Created on'] = "ایجاد شده در";
$lang['Creation date'] = "تاریخ ایجاد";
$lang['Current password is wrong'] = "گذرواژه وارد شده اشتباه است.";
$lang['Dimensions'] = "ابعاد";
$lang['Display'] = "نمایش";
$lang['Each listed rule must be satisfied.'] = "همه‌ی معیارهای ذکر شده باید کامل شوند";
$lang['Email address'] = "آدرس‌های ایمیل";
$lang['Enter your personnal informations'] = "داده‌های خصوصی خود را وارد نمایید";
$lang['Error sending email'] = "خطا در ارسال ایمیل";
$lang['File name'] = "نام فایل";
$lang['File'] = "فایل";
$lang['Filesize'] = "اندازه‌فایل";
$lang['Filter and display'] = "فیلتر کن و نمایش بده";
$lang['Filter'] = "فیلتر";
$lang['Forgot your password?'] = "گذرواژه خود را فراموش کرده‌اید؟";
$lang['Go through the gallery as a visitor'] = "هدایت بازدید کننده به گالری";
$lang['Help'] = "کمک";
$lang['Identification'] = "شناسایی";
$lang['Photos only RSS feed'] = "Images only RSS feed";
$lang['Keyword'] = "کلید واژه‌ها";
$lang['Links'] = "لینک‌ها";
$lang['N/A'] = "N/A";
$lang['New on %s'] = "جدید در %s";
$lang['New password confirmation does not correspond'] = "تایید گذرواژه با گذرواژه مطابقت ندارند!";
$lang['Notification'] = "خبرنامه";
$lang['Number of items'] = "تعداد آیتم‌ها";
$lang['Original dimensions'] = "ابعاد اصلی";
$lang['Password forgotten'] = "گذرواژه فراموش شده";
$lang['Password'] = "گذرواژه";
$lang['Post date'] = "تاریخ ارسال پست";
$lang['Posted on'] = "ارسال شده در";
$lang['Profile'] = "پروفایل";
$lang['Quick connect'] = "اتصال سریع";
$lang['RSS feed'] = "خوراک RSS";
$lang['Register'] = "ثبت نام";
$lang['Registration'] = "ثبت نام کاربر جدید";
$lang['Related tags'] = "برچسب‌های مربوطه";
$lang['Reset'] = "ریست";
$lang['Retrieve password'] = "بازیابی گذرواژه";
$lang['Search rules'] = "قوانین جستجو";
$lang['Search tags'] = "جستجوی برچسب‌ها";
$lang['Search'] = "جستجو";
$lang['display available tags'] = "نمایش برچسب‌های موجود";
$lang['Since'] = "Since";
$lang['Sort by'] = "مرتب سازی با";
$lang['Sort order'] = "Sort order";
$lang['Tag'] = "برچسب";
$lang['Tags'] = "برچسب‌ها";
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = "سرویس‌دهنده جدید RSS جدیدترین چیزهای سایت شما را از قبیل عکس‌های جدید ، دسته‌های بروز رسنای شده ‌، نظرات جدید را با یک خواننده RSS نمایش می‌دهد.";
$lang['Unknown feed identifier'] = "خوراک خور شناسایی نشد!";
$lang['User comments'] = "نطرات کاربران";
$lang['Username'] = "نام‌کاربری";
$lang['Visits'] = "نمایش‌ها";
$lang['Webmaster'] = "وب‌مستر(مدیر)";
$lang['Week %d'] = "%d هفته";
$lang['About Piwigo'] = "درباره Piwigo";
$lang['You are not authorized to access the requested page'] = "شما مجاز به مشاهده این صفحه نیستید.";
$lang['add to caddie'] = "add to caddie";
$lang['add this photo to your favorites'] = "افزودن این عکس به علاقه مندی‌های من";
$lang['Administration'] = "مدیریت";
$lang['all'] = "همه";
$lang['ascending'] = "ascending";
$lang['author(s) : %s'] = "نویسنده(ها) : %s";
$lang['Expand all albums'] = "بازکردن تمام دسته‌ها";
$lang['posted after %s (%s)'] = "ارسال‌های بعد از %s (%s)";
$lang['posted before %s (%s)'] = "ارسال‌های قبل از %s (%s)";
$lang['posted between %s (%s) and %s (%s)'] = "ارسال‌های بین %s (%s) و %s (%s)";
$lang['posted on %s'] = "ارسال شده در %s";
$lang['Best rated'] = "بهترین امتیاز داده شده";
$lang['display best rated photos'] = "نمایش آیتم‌هایی که بیشترین امتیاز را دارند";
$lang['caddie'] = "Caddie";
$lang['Calendar'] = "تقویم";
$lang['All'] = "همه";
$lang['display each day with photos, month per month'] = "هر روز با نمایش عکس‌های جدید ، ماه به ماه";
$lang['View'] = "نمایش";
$lang['chronology_monthly_calendar'] = "تقویم ماهیانه";
$lang['chronology_monthly_list'] = "لیست ماهیانه";
$lang['chronology_weekly_list'] = "لیست هفتگی";
$lang['Click here if your browser does not automatically forward you'] = "اگر مرورگر شما به صورت اتوماتیک ارجاع داده نشد، این‌جا را کلیک کنید.";
$lang['comment date'] = "تاریخ نظر";
$lang['Comment'] = "نظر";
$lang['Your comment has been registered'] = "نظر شما در سیستم ثبت شد";
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = "سیستم ضد هرزنامه: لطفا چند لحظه قبل از ارسال مجدد نظر منتظر بمانید!";
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = "نظر شما در سیستم ثبت نشد چون شما قوانین آن را زیر پا گذاشتید!";
$lang['An administrator must authorize your comment before it is visible.'] = "یک مدیر باید نظر شما را ایید کند تا نمظر شما قابل نمایش شود!";
$lang['This login is already used by another user'] = "This login is already used by another user";
$lang['Comments'] = "نظرات";
$lang['Add a comment'] = "افزودن نظر";
$lang['created after %s (%s)'] = "ایجاد شده بعد از %s (%s)";
$lang['created before %s (%s)'] = "ایجاد شده قبل از %s (%s)";
$lang['created between %s (%s) and %s (%s)'] = "ایجاد شده بین %s (%s) و %s (%s)";
$lang['created on %s'] = "ایجاد شده در %s";
$lang['Customize'] = "سفارشی کردن";
$lang['Your Gallery Customization'] = "گالری شما سفارشی سازی شد!";
$lang['day'][0] = "یک‌شنبه";
$lang['day'][1] = "دوشنبه";
$lang['day'][2] = "سه‌شنبه";
$lang['day'][3] = "چهارشنبه";
$lang['day'][4] = "پنج‌شنبه";
$lang['day'][5] = "جمعه";
$lang['day'][6] = "شنبه";
$lang['Default'] = "پیش‌فرض";
$lang['delete this photo from your favorites'] = "حذف این تصویر از علاقه‌مندی‌های من‌";
$lang['Delete'] = "حذف";
$lang['descending'] = "descending";
$lang['download'] = "دریافت";
$lang['download this file'] = "دریافت این فایل";
$lang['edit'] = "ویرایش";
$lang['wrong date'] = "تاریخ اشتباه است";
$lang['excluded'] = "excluded";
$lang['Your favorites'] = "علاقه‌مندی‌های‌من";
$lang['display your favorites photos'] = "نمایش تصاویر مورد علاقه‌ من";
$lang['Favorites'] = "علاقه‌مندی‌ها";
$lang['First'] = "اول";
$lang['The gallery is locked for maintenance. Please, come back later.'] = "این گالری برای بروز رسانی قفل شده‌ است ؛ لطفا بعدا مراجعه کنید.";
$lang['Page generated in'] = "صفحه ایجاد شده در";
$lang['guest'] = "میهمان";
$lang['Hello'] = "سلام";
$lang['available for administrators only'] = "فقط در دسترس مدیر";
$lang['display this album'] = "نمایش عکس‌هایی که در ریشه این دسته است";
$lang['display last user comments'] = "نمایش آخرین نظرات کاربران";
$lang['customize the appareance of the gallery'] = "سفارشی کردن نمایش گالری";
$lang['search'] = "جستجو";
$lang['Home'] = "خانه";
$lang['in this album'] = "در این دسته";
$lang['in %d sub-album'] = "در زیر دسته %d";
$lang['in %d sub-albums'] = "در زیر دسته‌های %d";
$lang['included'] = "ضمیمه شده";
$lang['Invalid password!'] = "گذرواژه اشتباه است!";
$lang['Language'] = "زبان";
$lang['last %d days'] = "در %d روز گذشته";
$lang['Last'] = "آخرین";
$lang['Logout'] = "خروج";
$lang['E-mail address'] = "آدرس ایمیل";
$lang['obligatory'] = "اجباری";
$lang['Maximum photo height'] = "حداکثر طول تصویر";
$lang['Maximum height must be a number superior to 50'] = "حداکثر طول تصویر باید عددی بزرگتر از 50 باشد";
$lang['Maximum photo width'] = "حداکثر عرض تصویر";
$lang['Maximum width must be a number superior to 50'] = "حداکثر عرض تصویر باید عددی بزرگتر از 50 باشد";
$lang['display a calendar by creation date'] = "نمایش یک تقویم بر اساس تاریخ ایجاد";
$lang['display all photos in all sub-albums'] = "نمایش تمام تصاویر";
$lang['return to normal view mode'] = "بازگشت به حالت عادی";
$lang['display a calendar by posted date'] = "نمایش یک تقویم براساس تاریخ ارسال";
$lang['month'][10] = "اکتبر";
$lang['month'][11] = "نوامبر";
$lang['month'][12] = "دسامبر";
$lang['month'][1] = "ژانویه";
$lang['month'][2] = "فوریه";
$lang['month'][3] = "مارس";
$lang['month'][4] = "آوریل";
$lang['month'][5] = "مه";
$lang['month'][6] = "ژوئن";
$lang['month'][7] = "جولای";
$lang['month'][8] = "آگوست";
$lang['month'][9] = "سپتامبر";
$lang['Most visited'] = "بیشترین بازدید";
$lang['display most visited photos'] = "نمایش عکس‌هایی که بیشترین بازدید را داشته‌اند.";
$lang['Unknown identifier'] = "ناشناخته!";
$lang['New password'] = "گذرواژه جدید";
$lang['Rate this photo'] = "امتیاز دادن به این تصویر";
$lang['Next'] = "بعدی";
$lang['no rate'] = "بدون امتیاز";
$lang['Photos posted within the last %d day.'] = "فقط پست‌هایی را نمایش بده که در %d روز قبل ارسال شده‌اند.";
$lang['Photos posted within the last %d days.'] = "فقط پست‌هایی را نمایش بده که در %d روز قبل ارسال شده‌اند.";
$lang['password updated'] = "گذرواژه بروزرسانی شد";
$lang['Recent period must be a positive integer value'] = "Recent period must be a positive integer value";
$lang['photo'] = "عکس";
$lang['Click on the photo to see it in high definition'] = "روی تصاویر کلیک کنید تا آن‌ها را با بالاترین کیفیت مشاهده نمایید.";
$lang['Show file metadata'] = "نمایش فایل ابرداده(metadata)";
$lang['Powered by'] = "به قدرت رسیده توسط";
$lang['Preferences'] = "تنظیمات";
$lang['Previous'] = "قبلی";
$lang['Random photos'] = "تصاویر تصادفی";
$lang['display a set of random photos'] = "تنظیم نمایش تصاویر تصادفی";
$lang['Recent albums'] = "دسته‌های اخیر";
$lang['display recently updated albums'] = "نمایش دسته‌های اخیر بروز رسانی شد";
$lang['Recent period'] = "Recent period";
$lang['Recent photos'] = "تصاویر اخیر";
$lang['display most recent photos'] = "نمایش بیشترین تصاویر نمایش داده شده";
$lang['Redirection...'] = "در حال ارجاع...";
$lang['Please, enter a login'] = "لطفا با اطلاعات خو وارد شوید.";
$lang['login mustn\'t end with a space character'] = "اطلاعات ورود نباید دارای فاصله(Space) باشد.";
$lang['login mustn\'t start with a space character'] = "اطلاعات ورود نباید با فاصله(Space) شروع شود";
$lang['this login is already used'] = "این اطلاعات ورود از قبل وجود دارد";
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = "آدرس ایمیل باید چیزی شبیه به xxx@yyy.eee باشد. (مانند : jack@altern.org)";
$lang['please enter your password again'] = "لطفا گذرواژه خود را مجددا وارد نمایید";
$lang['Auto login'] = "ورود اتوماتیک";
$lang['remove this tag from the list'] = "حذف این برچسب از لیست";
$lang['representative'] = "نماینده";
$lang['Search for Author'] = "جستجو برای نویسنده";
$lang['Search in albums'] = "جستجو در دسته";
$lang['Search by Date'] = "چستچو با تاریخ";
$lang['Date'] = "تاریخ";
$lang['End-Date'] = "تاریخ پایان";
$lang['Kind of date'] = "گروه تاریخ";
$lang['Search for words'] = "جستجو کلمات";
$lang['Search for all terms'] = "چستچو برای تمام قوانین";
$lang['Search for any terms'] = "جیتجو برای هر قانون";
$lang['Empty query. No criteria has been entered.'] = "شما هیچ قانونی برای جستجو معین نکرده‌اید!";
$lang['Search Options'] = "گزینه‌های جستجو";
$lang['Search results'] = "نتایج جستجو";
$lang['Search in sub-albums'] = "جستجو در زیر دسته‌ها";
$lang['searched words : %s'] = "نتایج جستجوی : %s";
$lang['Contact'] = "ارتباط";
$lang['set as album representative'] = "تنظیم یک نماینده دسته";
$lang['Show number of comments'] = "نمایش تعداد نظرات";
$lang['Show number of hits'] = "نمایش تعداد بازدیدها";
$lang['slideshow'] = "نمایش به صورت اسلاید";
$lang['stop the slideshow'] = "توقف اسلاید";
$lang['Specials'] = "پنل ویژه";
$lang['SQL queries in'] = "SQL queries in";
$lang['display only recently posted photos'] = "فقط آخرین تصاویر ازسال شده را نمایش بده";
$lang['return to the display of all photos'] = "بازگشت به نمایش تمام تصاویر";
$lang['the beginning'] = "شروع";
$lang['Interface theme'] = "رابط قالب";
$lang['Thumbnails'] = "عکس‌ریزه";
$lang['Menu'] = "منو";
$lang['A comment on your site'] = "یادداشتی روی سایت شما";
$lang['today'] = "امروز";
$lang['Update your rating'] = "بروزرسانی امتیاز";
$lang['wrong filename'] = "نام‌فایل استباه است";
$lang['the username must be given'] = "نام کاربری ضرور است";
$lang['useful when password forgotten'] = "قابل استفاده برای گذرواژه فراموش شده";
$lang['Quick search'] = "جستجوی سریع";
$lang['Connected user: %s'] = "کاربرهای متصل شده به سیستم: %s";
$lang['IP: %s'] = "IP: %s";
$lang['Browser: %s'] = "Browser: %s";
$lang['Author: %s'] = "نویسنده: %s";
$lang['Comment: %s'] = "نظر: %s";
$lang['Comment by %s'] = "%s میگه:";
$lang['User: %s'] = "User: %s";
$lang['Email: %s'] = "Email: %s";
$lang['Admin: %s'] = "Admin: %s";
$lang['Registration of %s'] = "Registration of %s";
$lang['Album: %s'] = "Category: %s";
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = "وضعیت بد برای کاربر \"میهمان\" ، وضعیت پیش‌فرض . لطفا این موضوع را با وبمستر(مدیر‌سایت) در میان بگذارید.";
$lang['this email address is already in use'] = "یک کاربر دیگر این آدرس ایمیل را در سیستم ثبت کرده است.";
$lang['Album results for'] = "نتایج دسته برای";
$lang['Tag results for'] = "نتایج برچسب برای";
$lang['from %s to %s'] = "از %s تا %s";
$lang['Play of slideshow'] = "شروع نمایش به صورت اسلاید";
$lang['Pause of slideshow'] = "توقف نمایش اسلاید";
$lang['Repeat the slideshow'] = "تکرار نمایش اسلاید";
$lang['Not repeat the slideshow'] = "اسلاید را تکرار نکن";
$lang['Reduce diaporama speed'] = "کاهش سرعت اسلاید";
$lang['Accelerate diaporama speed'] = "افزایش سرعت اسلاید";
$lang['Submit'] = "ثبت";
$lang['Yes'] = "بله";
$lang['No'] = "خیر";
$lang['%d photo'] = "%d تصویر";
$lang['%d photos'] = "%d تصویر";
$lang['%d photo is also linked to current tags'] = "%d تصویر هم به این برچسب مربوط هستند.";
$lang['%d photos are also linked to current tags'] = "%d تصویر هم به این برچسب مربوط هستند.";
$lang['display photos linked to this tag'] = "نمایش تصاویری که مربوط به این برچسب هستند";
$lang['photos posted during the last %d days'] = "تصاویری که در %d روز گذشته ارسال شدهخ‌اند.";
$lang['Piwigo Help'] = "Piwigo help";
$lang['Rank'] = "امتیاز";
$lang['group by letters'] = "گروه حروف";
$lang['letters'] = "حروف";
$lang['show tag cloud'] = "نمایش ابر(cloud) برچسب";
$lang['cloud'] = "ابر(cloud)";
$lang['Reset to default values'] = "بازگرداندن به مقدارهای پیش‌فرض";
$lang['delete all photos from your favorites'] = "حذف تمام تصاویر از علاقه‌مندی‌های شما";
$lang['Sent by'] = "ارسال به وسیله";
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = "شما در تنظیمات مرورگر خود کوکی ها را بلاک کردید یا مرورگر شما از کوکی پشتیبانی نمی‌کند. برای ورود به محیط کاربری باید کوکی‌ها فعال باشند.";
$lang['edit this comment'] = "ویرایش این نظر";
$lang['Edit a comment'] = "ویرایش یک نظر";
$lang['Are you sure?'] = "شما مطمئن هستید؟";
$lang['(!) This comment requires validation'] = '(!) این نظر نیاز به تایید دارد';
$lang['Welcome'] = 'خوش‌آمدید!';
$lang['Welcome to your Piwigo photo gallery!'] = 'به گالری تصاویر Piwigo خود خوش آمدید.';
$lang['... or browse your empty gallery'] = '... یا یک گالری خالی را مشاهده کنید!';
$lang['... or please deactivate this message, I will find my way by myself'] = '... یا لطفا این پیام را غیرفعال نمایید ؛ من راهم را خودم پیدا خواهم کرد!';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = '%s خوش آمدید ، گالری تصاویر شما خالی است.';
$lang['I want to add photos'] = 'من می‌خواهم تصاویر جدید اضاف کنم!';
$lang['Manage this user comment: %s'] = 'مدیریت نظرات این کاربر %s';
$lang['Email address is missing. Please specify an email address.'] = "کاربر فاقد آدرس ایمیل است. لطفا یکی آدرس ایمیل مشخص کنید.";
$lang['This author modified following comment:'] = 'این نویسنده این نظرات را تغییر داده است:';
$lang['This author removed the comment with id %d'] = 'این نویسنده ، نظری با شناسه %d را حذف کرده است.';
$lang['delete this comment'] = "حذف این نظر";
$lang['validate this comment'] = 'تایید این نظر';
$lang['html tags are not allowed in login'] = 'شما در فرم ورود مجاز به استفاده از كدهاي HTML نيستيد!';

?>